@@ -25,8 +25,8 @@ BloomFilter *bloomfilter_Create_Malloc(size_t max_num_elem, double error_rate,
     bf->bf_version = BF_CURRENT_VERSION;
     bf->elem_count = 0;
     bf->array = NULL;
-    memset(bf->reserved, sizeof(uint32_t) * 32, 0);
-    memset(bf->hash_seeds, sizeof(uint32_t) * 256, 0);
+    memset(bf->reserved, 0, sizeof(uint32_t) * 32);
+    memset(bf->hash_seeds, 0, sizeof(uint32_t) * 256);
     memcpy(bf->hash_seeds, hash_seeds, sizeof(uint32_t) * num_hashes);
     array = mbarray_Create_Malloc(num_bits);
     if (!array) {
@@ -57,8 +57,8 @@ BloomFilter *bloomfilter_Create_Mmap(size_t max_num_elem, double error_rate,
     bf->bf_version = BF_CURRENT_VERSION;
     bf->elem_count = 0;
     bf->array = NULL;
-    memset(bf->reserved, sizeof(uint32_t) * 32, 0);
-    memset(bf->hash_seeds, sizeof(uint32_t) * 256, 0);
+    memset(bf->reserved, 0,  sizeof(uint32_t) * 32);
+    memset(bf->hash_seeds, 0, sizeof(uint32_t) * 256);
     memcpy(bf->hash_seeds, hash_seeds, sizeof(uint32_t) * num_hashes);
     array = mbarray_Create_Mmap(num_bits, file, (char *)bf, sizeof(BloomFilter), oflags, perms);
     if (!array) {
@@ -144,6 +144,16 @@ BloomFilter * bloomfilter_Copy_Template(BloomFilter * src, char * filename, int
     return bf;
 }
 
+
+uint32_t _hash_long(uint32_t hash_seed, Key * key) {
+    Key newKey = {
+        .shash = (char *)&key->nhash,
+        .nhash = sizeof(key->nhash)
+    };
+
+    return _hash_char(hash_seed, &newKey);
+}
+
 /*
 CODE FOR djb HASH...
 uint32_t _hash_char(uint32_t hash_seed, Key * key) {
@@ -156,13 +166,6 @@ uint32_t _hash_char(uint32_t hash_seed, Key * key) {
     return result;
 }
 
-uint32_t _hash_long(uint32_t hash_seed, Key * key) {
-    return 5381 + (33 * (key->nhash ^ hash_seed));
-}
-*/
-
-/*
-
 CODE TO USE SHA512..
 
 #include <openssl/evp.h>
@@ -182,17 +185,8 @@ uint32_t _hash_char(uint32_t hash_seed, Key * key) {
     return *(uint32_t *)result_buffer;
 }
 
-uint32_t _hash_long(uint32_t hash_seed, Key * key) {
-    Key newKey = {
-        .shash = (char *)key->nhash,
-        .nhash = sizeof(key->nhash)
-    };
+CODE TO USE md5sum
 
-    return _hash_char(hash_seed, &newKey);
-}
-*/
-
-/*
 #include "md5.h"
 uint32_t _hash_char(uint32_t hash_seed, Key * key) {
     md5_state_t state;
@@ -205,29 +199,14 @@ uint32_t _hash_char(uint32_t hash_seed, Key * key) {
     md5_finish(&state, result);
     return *(uint32_t *)(&result[4]);
 }
+*/
 
-uint32_t _hash_long(uint32_t hash_seed, Key * key) {
-    Key newKey = {
-        .shash = (char *)&key->nhash,
-        .nhash = sizeof(key->nhash)
-    };
-
-    return _hash_char(hash_seed, &newKey);
-}
-//*/
-
-//*
+/* Code for SuperFast */
 #include "superfast.h"
 uint32_t _hash_char(uint32_t hash_seed, Key * key) {
 	return SuperFastHash(key->shash, key->nhash, hash_seed);
 }
 
-uint32_t _hash_long(uint32_t hash_seed, Key * key) {
-	return SuperFastHash((char*)key->nhash, sizeof(key->nhash), hash_seed);
-}
-//*/
-
-
 #if 0
 int main(int argc, char **argv)
 {
